/*
 * Custom function used to generate the output of the override.css file
 */

var generateOverride = function (params) {   
    let output = '';

   if(params.minFontSize !== '1' || params.maxFontSize !== '1.2') {
        output += `
        html {
               font-size: ${params.minFontSize}rem;
        }

        @media screen and (min-width: 20rem) {
               html {
                   font-size: calc(${params.minFontSize}rem + (${params.maxFontSize} - ${params.minFontSize}) * ((100vw - 20rem) / 46));
                }
        }

        @media screen and (min-width: 66rem) {
               html { 
                   font-size: ${params.maxFontSize}rem;
               }
        }`;    	 
   }

   if(params.textColor !== '#111111') {
        output += `
        body {
               color: ${params.textColor};  
        }`;   
   }
	
   if(params.headingColor !== '#111111') {
        output += `
        h1,
        h2,
        h3,
        h4,
        h5,
        h6,
        .inverse {
               color: ${params.headingColor};           
        }`;    	 
   }
   
   if (params.fontHeadignsWeight !== '400' || params.fontHeadingsTransform !== 'uppercase') {
        output += `
        h1,
        h2,
        h3,
        h4,
        h5,
        h6 {
               font-weight: ${params.fontHeadignsWeight};              
               text-transform: ${params.fontHeadingsTransform};  
        }`;
   } 
	
   if(params.linkColor !== '#6B78B4') {
        output += `
        a,
        .inverse:hover,
        .inverse:active,
        .inverse:focus {
               color: ${params.linkColor};   
        }
        .navbar .navbar__menu > li.active a {
               color: ${params.linkColor}; 

          }`;    	 
   }
	
   if(params.linkHoverColor !== '#6B78B4') {
        output += `
        a:hover,
        a:active,
        a:focus,
        .footer a:hover {
               color: ${params.linkHoverColor}; 
        }

        .navbar .navbar__menu li a:active,
        .navbar .navbar__menu li a:focus,
        .navbar .navbar__menu li a:hover,
        .navbar .navbar__menu li span[aria-haspopup="true"]:active,
        .navbar .navbar__menu li span[aria-haspopup="true"]:focus,
        .navbar .navbar__menu li span[aria-haspopup="true"]:hover {
               color: ${params.linkHoverColor};
        }

        .navbar .navbar__menu > li:hover > a,
        .navbar .navbar__menu > li:hover > span[aria-haspopup="true"] {
           color: ${params.linkHoverColor};
        }`;    	 
   }
    
   if(params.primaryColor) {
        output += `
        .cookie-popup,
        .cookie-popup__save {
               background: ${params.primaryColor};      
        }`;    	 
   }
    
   if(params.primaryColor !== '#6B78B4') {
        output += `      
        ::selection {
               background: ${params.primaryColor};                     
        }

        .btn:hover, 
        [type=button]:hover,
        [type=submit]:hover,
        button:hover, 
        .btn:focus, 
        [type=button]:focus,
        [type=submit]:focus,
        button:focus,
        .btn:active, 
        [type=button]:active,
        [type=submit]:active,
        button:active,
       .navbar .navbar__submenu {
               background: ${params.primaryColor};      
        }

        blockquote,
        [type=text]:focus,
        [type=url]:focus,
        [type=tel]:focus,
        [type=number]:focus,
        [type=email]:focus,
        [type=search]:focus,
        textarea:focus,
        select:focus,
        select[multiple]:focus {
               border-color: ${params.primaryColor};
        }

        input[type=checkbox]:checked + label:before{
               background-image: url("data:image/svg+xml;charset=UTF-8,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 11 8'%3e%3cpolygon points='9.53 0 4.4 5.09 1.47 2.18 0 3.64 2.93 6.54 4.4 8 5.87 6.54 11 1.46 9.53 0' fill='${params.primaryColor.replace('#', '%23')}'/%3e%3c/svg%3e");
        }

        input[type=radio]:checked + label:before {
               background-image: url("data:image/svg+xml;charset=UTF-8,%3csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 8 8'%3e%3ccircle cx='4' cy='4' r='4' fill='${params.primaryColor.replace('#', '%23')}'/%3e%3c/svg%3e");   
        }`;    	 
   }
	
   if(params.pageWidth !== '64rem') {
        output += `   
        .container {
               max-width: calc(${params.pageWidth} + 8%); 
        }

        @media all and (min-width: 56.25em) {
               .container > header.is-sticky > div {
                   max-width: ${params.pageWidth}; 
               }
        }

        @media all and (min-width: 56.25em) {
               .hero > header {
                   max-width: calc(${params.pageWidth} + 8%);
               }
        }

        @media all and (min-width: 56.25em) {
               .hero--narrow {
                   left: calc((100% - ${params.pageWidth}) /2);
                   width: ${params.pageWidth};
               }
        }

        @media all and (min-width: 75em) {
               .post__image--wide {
                   margin-left: calc((100% - ${params.pageWidth}) /2);
                   margin-right: calc((100% - ${params.pageWidth}) /2);
               }
        }

        .search__input {  
               width: ${params.pageWidth};  
          }`;
   }	
    
   if(params.layoutType === 'rounded') {
        output += ` 
        .card,
        .btn,
        [type=button],
        [type=submit],
        [type=text],
        [type=url],
        [type=tel],
        [type=number],
        [type=email],
        [type=search],
        textarea,
        select,
        button, .post__share > a, 
        .post__tag > li > a,
        .navbar .navbar__submenu,
        .hero__image > figcaption,
        .post__related__wrap figure a > img {
               border-radius: ${params.layoutTypeBorderRadius}px;
          }`;    	 
   }
  
   if(params.backgroundHero !== '#111111' || params.heightMinHero !== '20rem' || params.heightMaxHero !== '45rem') {
        output += `   
        .hero {
               background: ${params.backgroundHero}; 
               min-height: ${params.heightMinHero};
               max-height: ${params.heightMaxHero};  
        }

        .hero__image::after {
               background: ${params.backgroundHero}; 
        }

        .hero__image > figcaption {
               background: ${params.backgroundHero}; 

        }

        @media all and (max-width: 56.1875em) {
               .hero__image > img {
                   min-height: ${params.heightMinHero}; 
               }   
          }`;    	 
   }
	
   if(params.heightMaxHero !== '45rem') {
        output += ` 
        @media all and (min-width: 56.25em) {
               .hero__image > img {
                   height: ${params.heightMaxHero};
               }
          }`;    	 
   }
	
   if(params.opacityHero !== '0.6') {
	  output += `
        .hero__image::after  {
               opacity: ${params.opacityHero};
         }`;    	 
   }
	
   if(params.cardsHeight !== '20rem') {
        output += ` 
        .card,
        .card__image img {
               height: ${params.cardsHeight};  
        }`;    	 
   }	
	
   if(params.cardsColor !== '#111111' || params.cardsOpacity !== '0.4') {
        output += ` 
        .card__image > a:after  {
               background: ${params.cardsColor};
               opacity: ${params.cardsOpacity}; 
        }

        .card:after,
        .card:hover .card__image > a:after {
               background: ${params.cardsColor};
        }`;    	 
   }	
	
   if(params.cardsAccentColor !== '#6B78B4' || params.cardsAccentOpacity !== '0.95') {
        output += `  
        .category--layout-1 .card:nth-child(6n-5) .card__image > a:after,
        .category--layout-2 .card:nth-child(8n-6) .card__image > a:after,         
        .category--layout-3 .card:nth-child(8n-6) .card__image > a:after, 
        .category--layout-4 .card:nth-child(8n-6) .card__image > a:after,        
        .category--layout-5 .card:nth-child(5n-2) .card__image > a:after,
        .category--layout-6 .card:nth-child(3n) .card__image > a:after {
               background: ${params.cardsAccentColor};
               opacity: ${params.cardsAccentOpacity};	
         }`;    	 
   }
	
   if(params.cardImgScale !== '1.6' || params.cardsImgRotate !== '-10') {
        output += ` 
        .card:hover .card__image img {
               -webkit-transform: scale(${params.cardImgScale}) rotate(${params.cardsImgRotate}deg);
               transform: scale(${params.cardImgScale}) rotate(${params.cardsImgRotate}deg);
         }`;    	 
   }
    
   if(params.cardsGap !== '0.75') {
        output += `   
        .category {
               grid-gap: ${params.cardsGap}rem;
        }
        .hero {
               margin-bottom: ${params.cardsGap}rem;
        }`;    	 
   }	
    
   if (params.submenu === 'custom') {
        output += `
        .navbar .navbar__submenu {
               width: ${params.submenuWidth}px;     
        }

        .navbar .navbar__menu--wide .has-submenu:active > .navbar__submenu,
        .navbar .navbar__menu--wide .has-submenu:focus > .navbar__submenu,
        .navbar .navbar__menu--wide .has-submenu:hover > .navbar__submenu  {
               min-width: ${params.submenuWidth}px;
        }

        .navbar .has-submenu .has-submenu:active > .navbar__submenu,
        .navbar .has-submenu .has-submenu:focus > .navbar__submenu,
        .navbar .has-submenu .has-submenu:hover > .navbar__submenu {
               left: ${params.submenuWidth}px;  
        }
        .navbar .has-submenu .has-submenu:active > .navbar__submenu.is-right-submenu,
        .navbar .has-submenu .has-submenu:focus > .navbar__submenu.is-right-submenu,
        .navbar .has-submenu .has-submenu:hover > .navbar__submenu.is-right-submenu {
               left: -${params.submenuWidth}px; 
        }`;
    }     
	
   if(params.galleryItemGap !== '0.5rem') {
        output += `   
        .gallery__item {
               padding: ${params.galleryItemGap}; 
        } 
        .gallery {   
               margin: calc(1.5rem + 1vw) -${params.galleryItemGap}; 
        }`;    	 
   }	
	
   if(params.lazyLoad) {
        if(params.lazyLoadEffect !== 'blur') {
            output += ` 
            .lazyload,
            .lazyloading {
               opacity: 0;
            }
            .lazyloaded {
               opacity: 1;
               transition: opacity 1s cubic-bezier(0.215, 0.61, 0.355, 1); 
            }`;    	 
        }

        if (params.lazyLoadEffect === 'blur') {
            output += ` 
            .lazyload,
            .lazyloading {
               -webkit-filter: blur(5px);
               filter: blur(5px);
               transition: filter 400ms, -webkit-filter 400ms;
            }
            .lazyloaded {
               -webkit-filter: blur(0);
               filter: blur(0);
            }`;
        }
    }
	
 return output;
}

module.exports = generateOverride;
